import { useState } from "react";
import Image from "next/image";
import { Button, Card, CardActions, CardContent, Divider } from "@mui/material";
import QuizQuestionAnswerBox from "./components/QuizQuestionAnswerBox";
import { ChevronLeft, ChevronRight } from "@mui/icons-material";
import QuestionDescription from "@/components/sections/forPages/components/QuestionDescription";

const QuizQuestionCard = ({
  question,
  handleNextQuestion,
  handlePrevQuestion,
}) => {
  const [selectedAnswer, setSelectedAnswer] = useState(null);
  const [openDesc, setOpenDesc] = useState(false);
  const handleSelectAnswer = (selectedAnswerId) => {
    if (selectedAnswer === null) {
      setSelectedAnswer(selectedAnswerId);
    }
  };
  return (
    <Card
      sx={{
        width: "100%",
        display: "flex",
        flexDirection: "column",
        justifyContent: "space-between",
      }}
      className="h-[90vh] md:h-[50vh] "
    >
      <QuestionDescription
        open={openDesc}
        handleClose={() => setOpenDesc(false)}
        question={question}
        correctAnswer={question.answers.find(
          (item) => item.id === question.trueAnswerId
        )}
      />
      <CardContent className="w-full flex flex-col justify-between  flex-1 gap-3">
        <div className="w-full h-full  flex flex-col  lg:flex-row gap-2 ">
          <div className=" w-full lg:w-[70%] flex flex-1 min-h-full h-full flex-col gap-6 ">
            <strong>{question.questionText}</strong>
            <div
              className={`w-full ${
                question.answersType === "text"
                  ? "flex flex-col gap-3"
                  : "grid grid-cols-2 md:grid-cols-4 gap-3 h-[250px]"
              }`}
            >
              {question?.answers?.map((answer, answerIndex) => (
                <QuizQuestionAnswerBox
                  key={answerIndex}
                  answer={answer}
                  trueAnswerId={question.trueAnswerId}
                  onSelect={() => handleSelectAnswer(answer.id)}
                  selectedAnswerId={selectedAnswer}
                  answersType={question.answersType}
                />
              ))}
            </div>
          </div>
          {question.questionImage && question.questionImage !== "" && (
            <div className="w-full lg:w-[30%] h-[179px] md:h-[200px] lg:h-full order-first lg:order-last flex items-start justify-center p-3 ">
              <Image
                width={"0"}
                height={"0"}
                className="w-auto h-full object-contain max-h-56"
                sizes="100vw"
                src={question.questionImage}
                alt={question.questionImageAlt}
                title={question.questionImageTitle}
              />
            </div>
          )}
        </div>
        <Divider />
      </CardContent>
      <CardActions
        sx={{
          display: "flex",
          flexDirection: "column",
          gap: 2,
          width: "100%",
          alignItems: "flex-end",
        }}
      >
        <Button
          onClick={() => setOpenDesc(true)}
          variant="contained"
          className="w-full md:w-[250px]"
        >
          توضیحات
        </Button>
        <div className="w-full flex justify-between">
          <Button
            startIcon={<ChevronRight />}
            variant="outlined"
            onClick={handlePrevQuestion}
          >
            سوال قبلی{" "}
          </Button>
          <Button
            endIcon={<ChevronLeft />}
            variant="outlined"
            onClick={handleNextQuestion}
          >
            سوال بعدی{" "}
          </Button>
        </div>
      </CardActions>
    </Card>
  );
};

export default QuizQuestionCard;
